@@ -498,6 +498,8 @@ ESCAPES = {
 '&eqcirc;': '≖',
 '&eqcolon;': '≕',
 '&eqsim;': '≂',
+'&epsilon;': 'ε',
+'&Epsilon;': 'Ε',
 '&eqslantgtr;': '⪖',
 '&eqslantless;': '⪕',
 '&Equal;': '⩵',
@@ -1306,6 +1308,8 @@ ESCAPES = {
 '&olt;': '⧀',
 '&omacr;': 'ō',
 '&Omacr;': 'Ō',
+'&omicron;': 'ο',
+'&Omicron;': 'Ο',
 '&omega;': 'ω',
 '&Omega;': 'Ω',
 '&omid;': '⦶',
